/**
   @author Shin'ichiro Nakaoka
*/

#include "SimulationBar.h"
#include "SimulatorItem.h"
#include <cnoid/ItemTreeView>
#include <cnoid/MessageView>
#include <boost/bind.hpp>

#include "xpm/startsimulation.xpm"
#include "xpm/stopsimulation.xpm"

using namespace std;
using namespace boost;
using namespace cnoid;


SimulationBar* SimulationBar::instance()
{
    static SimulationBar* instance = new SimulationBar();
    return instance;
}


SimulationBar::SimulationBar()
    : ToolBar("SimulationBar"),
      os(MessageView::mainInstance()->cout())
{
    addButton(startsimulation, tr("Start Simulation"))->sigClicked().connect(
        bind(&SimulationBar::onStartSimulationActivated, this));

    addButton(stopsimulation, tr("Stop Simulation"))->sigClicked().connect(
        bind(&SimulationBar::onStopSimulationActivated, this));

    se3Toggle = addToggleButton(tr("SE3"), tr("Output all link positions as SE3 pose seq data"));
    se3Toggle->setChecked(false);
}


SimulationBar::~SimulationBar()
{

}


void SimulationBar::onStartSimulationActivated()
{
    SimulatorItemPtr simulatorItem =
        ItemTreeView::mainInstance()->selectedItem<SimulatorItem>();

    if(simulatorItem){
        simulatorItem->setAllLinkPositionOutputMode(se3Toggle->isChecked());
        simulatorItem->startSimulation();
    } else {
        os << "Simulation cannot start. No simulation item is selected." << endl;
    }
}


void SimulationBar::onStopSimulationActivated()
{
    SimulatorItemPtr simulatorItem =
        ItemTreeView::mainInstance()->selectedItem<SimulatorItem>();

    if(simulatorItem){
        if(simulatorItem->isSimulationRunning()){
            simulatorItem->stopSimulation();
        }
    }
}
